@@ -1,7 +1,9 @@
-from less.settings import LESS_EXECUTABLE, LESS_ROOT, LESS_OUTPUT_DIR
+from less import LessException
+from less.settings import LESS_EXECUTABLE, LESS_ROOT, LESS_OUTPUT_DIR, \
+        LESS_OPTIONS
 from django.conf import settings
 import logging
-import posixpath
+import urlparse
 import re
 import os
 import subprocess
@@ -20,14 +22,15 @@ class URLConverter(object):
     def __init__(self, content, source_path):
         self.content = content
         self.source_dir = os.path.dirname(source_path)
+        if not self.source_dir.endswith('/'):
+            self.source_dir = self.source_dir + '/'
 
     def convert_url(self, matchobj):
         url = matchobj.group(1)
         url = url.strip(' \'"')
         if url.startswith(('http://', 'https://', '/', 'data:')):
             return "url('%s')" % url
-        full_url = posixpath.normpath("/".join([self.source_dir, url]))
-        return "url('%s')" % full_url
+        return "url('%s')" % urlparse.urljoin(self.source_dir, url)
 
     def convert(self):
         return self.URL_PATTERN.sub(self.convert_url, self.content)
@@ -39,7 +42,7 @@ def compile_less(input, output, less_path):
     if not os.path.exists(less_root):
         os.makedirs(less_root)
 
-    args = [LESS_EXECUTABLE, input]
+    args = [LESS_EXECUTABLE] + LESS_OPTIONS + [input]
     popen_kwargs = dict(
         stdout=subprocess.PIPE,
         stderr=subprocess.PIPE,
@@ -51,7 +54,7 @@ def compile_less(input, output, less_path):
 
     if errors:
         logger.error(errors)
-        return False
+        raise LessException(errors)
 
     output_directory = os.path.dirname(output)
     if not os.path.exists(output_directory):
@@ -63,5 +66,3 @@ def compile_less(input, output, less_path):
     compiled_file = open(output, "w+")
     compiled_file.write(compiled_css.encode(settings.FILE_CHARSET))
     compiled_file.close()
-
-    return True
